@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,16 +20,15 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.workflows.executions_v1beta.services.executions import pagers
 from google.cloud.workflows.executions_v1beta.types import executions
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import ExecutionsTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import ExecutionsGrpcAsyncIOTransport
 from .client import ExecutionsClient
@@ -52,25 +49,20 @@ class ExecutionsAsyncClient:
     parse_execution_path = staticmethod(ExecutionsClient.parse_execution_path)
     workflow_path = staticmethod(ExecutionsClient.workflow_path)
     parse_workflow_path = staticmethod(ExecutionsClient.parse_workflow_path)
-
     common_billing_account_path = staticmethod(
         ExecutionsClient.common_billing_account_path
     )
     parse_common_billing_account_path = staticmethod(
         ExecutionsClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(ExecutionsClient.common_folder_path)
     parse_common_folder_path = staticmethod(ExecutionsClient.parse_common_folder_path)
-
     common_organization_path = staticmethod(ExecutionsClient.common_organization_path)
     parse_common_organization_path = staticmethod(
         ExecutionsClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(ExecutionsClient.common_project_path)
     parse_common_project_path = staticmethod(ExecutionsClient.parse_common_project_path)
-
     common_location_path = staticmethod(ExecutionsClient.common_location_path)
     parse_common_location_path = staticmethod(
         ExecutionsClient.parse_common_location_path
@@ -78,7 +70,8 @@ class ExecutionsAsyncClient:
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -93,7 +86,7 @@ class ExecutionsAsyncClient:
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -110,7 +103,7 @@ class ExecutionsAsyncClient:
 
     @property
     def transport(self) -> ExecutionsTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             ExecutionsTransport: The transport used by the client instance.
@@ -124,12 +117,12 @@ class ExecutionsAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, ExecutionsTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the executions client.
+        """Instantiates the executions client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -161,7 +154,6 @@ class ExecutionsAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = ExecutionsClient(
             credentials=credentials,
             transport=transport,
@@ -198,7 +190,6 @@ class ExecutionsAsyncClient:
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -229,7 +220,6 @@ class ExecutionsAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
 
@@ -293,7 +283,6 @@ class ExecutionsAsyncClient:
                 This corresponds to the ``execution`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -320,7 +309,6 @@ class ExecutionsAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
         if execution is not None:
@@ -370,7 +358,6 @@ class ExecutionsAsyncClient:
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -397,7 +384,6 @@ class ExecutionsAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -445,7 +431,6 @@ class ExecutionsAsyncClient:
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -472,7 +457,6 @@ class ExecutionsAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
