@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,23 +13,21 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
-from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple
+from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import grpc_helpers_async  # type: ignore
 from google.api_core import operations_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
+import packaging.version
 
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
 
 from google.cloud.workflows_v1.types import workflows
-from google.longrunning import operations_pb2 as operations  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
 from .base import WorkflowsTransport, DEFAULT_CLIENT_INFO
 from .grpc import WorkflowsGrpcTransport
 
@@ -57,7 +54,7 @@ class WorkflowsGrpcAsyncIOTransport(WorkflowsTransport):
     def create_channel(
         cls,
         host: str = "workflows.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -84,13 +81,15 @@ class WorkflowsGrpcAsyncIOTransport(WorkflowsTransport):
         Returns:
             aio.Channel: A gRPC AsyncIO channel object.
         """
-        scopes = scopes or cls.AUTH_SCOPES
+
+        self_signed_jwt_kwargs = cls._get_self_signed_jwt_kwargs(host, scopes)
+
         return grpc_helpers_async.create_channel(
             host,
             credentials=credentials,
             credentials_file=credentials_file,
-            scopes=scopes,
             quota_project_id=quota_project_id,
+            **self_signed_jwt_kwargs,
             **kwargs,
         )
 
@@ -98,7 +97,7 @@ class WorkflowsGrpcAsyncIOTransport(WorkflowsTransport):
         self,
         *,
         host: str = "workflows.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         channel: aio.Channel = None,
@@ -112,7 +111,8 @@ class WorkflowsGrpcAsyncIOTransport(WorkflowsTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -171,7 +171,6 @@ class WorkflowsGrpcAsyncIOTransport(WorkflowsTransport):
             # If a channel was explicitly provided, set it.
             self._grpc_channel = channel
             self._ssl_channel_credentials = None
-
         else:
             if api_mtls_endpoint:
                 host = api_mtls_endpoint
@@ -304,7 +303,9 @@ class WorkflowsGrpcAsyncIOTransport(WorkflowsTransport):
     @property
     def create_workflow(
         self,
-    ) -> Callable[[workflows.CreateWorkflowRequest], Awaitable[operations.Operation]]:
+    ) -> Callable[
+        [workflows.CreateWorkflowRequest], Awaitable[operations_pb2.Operation]
+    ]:
         r"""Return a callable for the create workflow method over gRPC.
 
         Creates a new workflow. If a workflow with the specified name
@@ -326,14 +327,16 @@ class WorkflowsGrpcAsyncIOTransport(WorkflowsTransport):
             self._stubs["create_workflow"] = self.grpc_channel.unary_unary(
                 "/google.cloud.workflows.v1.Workflows/CreateWorkflow",
                 request_serializer=workflows.CreateWorkflowRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["create_workflow"]
 
     @property
     def delete_workflow(
         self,
-    ) -> Callable[[workflows.DeleteWorkflowRequest], Awaitable[operations.Operation]]:
+    ) -> Callable[
+        [workflows.DeleteWorkflowRequest], Awaitable[operations_pb2.Operation]
+    ]:
         r"""Return a callable for the delete workflow method over gRPC.
 
         Deletes a workflow with the specified name.
@@ -354,14 +357,16 @@ class WorkflowsGrpcAsyncIOTransport(WorkflowsTransport):
             self._stubs["delete_workflow"] = self.grpc_channel.unary_unary(
                 "/google.cloud.workflows.v1.Workflows/DeleteWorkflow",
                 request_serializer=workflows.DeleteWorkflowRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["delete_workflow"]
 
     @property
     def update_workflow(
         self,
-    ) -> Callable[[workflows.UpdateWorkflowRequest], Awaitable[operations.Operation]]:
+    ) -> Callable[
+        [workflows.UpdateWorkflowRequest], Awaitable[operations_pb2.Operation]
+    ]:
         r"""Return a callable for the update workflow method over gRPC.
 
         Updates an existing workflow.
@@ -385,7 +390,7 @@ class WorkflowsGrpcAsyncIOTransport(WorkflowsTransport):
             self._stubs["update_workflow"] = self.grpc_channel.unary_unary(
                 "/google.cloud.workflows.v1.Workflows/UpdateWorkflow",
                 request_serializer=workflows.UpdateWorkflowRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["update_workflow"]
 
