@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,22 +13,20 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
-from typing import Callable, Dict, Optional, Sequence, Tuple
+from typing import Callable, Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core import grpc_helpers  # type: ignore
 from google.api_core import operations_v1  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+import google.auth  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.cloud.workflows_v1beta.types import workflows
-from google.longrunning import operations_pb2 as operations  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
 from .base import WorkflowsTransport, DEFAULT_CLIENT_INFO
 
 
@@ -54,7 +51,7 @@ class WorkflowsGrpcTransport(WorkflowsTransport):
         self,
         *,
         host: str = "workflows.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         channel: grpc.Channel = None,
@@ -68,7 +65,8 @@ class WorkflowsGrpcTransport(WorkflowsTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -179,7 +177,7 @@ class WorkflowsGrpcTransport(WorkflowsTransport):
     def create_channel(
         cls,
         host: str = "workflows.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -210,13 +208,15 @@ class WorkflowsGrpcTransport(WorkflowsTransport):
             google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
               and ``credentials_file`` are passed.
         """
-        scopes = scopes or cls.AUTH_SCOPES
+
+        self_signed_jwt_kwargs = cls._get_self_signed_jwt_kwargs(host, scopes)
+
         return grpc_helpers.create_channel(
             host,
             credentials=credentials,
             credentials_file=credentials_file,
-            scopes=scopes,
             quota_project_id=quota_project_id,
+            **self_signed_jwt_kwargs,
             **kwargs,
         )
 
@@ -296,7 +296,7 @@ class WorkflowsGrpcTransport(WorkflowsTransport):
     @property
     def create_workflow(
         self,
-    ) -> Callable[[workflows.CreateWorkflowRequest], operations.Operation]:
+    ) -> Callable[[workflows.CreateWorkflowRequest], operations_pb2.Operation]:
         r"""Return a callable for the create workflow method over gRPC.
 
         Creates a new workflow. If a workflow with the specified name
@@ -318,14 +318,14 @@ class WorkflowsGrpcTransport(WorkflowsTransport):
             self._stubs["create_workflow"] = self.grpc_channel.unary_unary(
                 "/google.cloud.workflows.v1beta.Workflows/CreateWorkflow",
                 request_serializer=workflows.CreateWorkflowRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["create_workflow"]
 
     @property
     def delete_workflow(
         self,
-    ) -> Callable[[workflows.DeleteWorkflowRequest], operations.Operation]:
+    ) -> Callable[[workflows.DeleteWorkflowRequest], operations_pb2.Operation]:
         r"""Return a callable for the delete workflow method over gRPC.
 
         Deletes a workflow with the specified name.
@@ -346,14 +346,14 @@ class WorkflowsGrpcTransport(WorkflowsTransport):
             self._stubs["delete_workflow"] = self.grpc_channel.unary_unary(
                 "/google.cloud.workflows.v1beta.Workflows/DeleteWorkflow",
                 request_serializer=workflows.DeleteWorkflowRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["delete_workflow"]
 
     @property
     def update_workflow(
         self,
-    ) -> Callable[[workflows.UpdateWorkflowRequest], operations.Operation]:
+    ) -> Callable[[workflows.UpdateWorkflowRequest], operations_pb2.Operation]:
         r"""Return a callable for the update workflow method over gRPC.
 
         Updates an existing workflow.
@@ -377,7 +377,7 @@ class WorkflowsGrpcTransport(WorkflowsTransport):
             self._stubs["update_workflow"] = self.grpc_channel.unary_unary(
                 "/google.cloud.workflows.v1beta.Workflows/UpdateWorkflow",
                 request_serializer=workflows.UpdateWorkflowRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["update_workflow"]
 
